## 简介

- 在控制台中用于彩色打印的包
- 采用的是亮色
- 支持多值打印
- 支持使用十六进制颜色值（如 `"FF00FF"` 或 `"#00FF00"`）打印对应颜色的文字

## 安装

```
pip install --index-url https://pypi.org/simple colorPrintConsole -U
```

## 使用

```python
from colorPrintConsole import ColorPrint

cp = ColorPrint()
cp.red("This is red.")
cp.green("This is green.")
cp.yellow("This is yellow.")
cp.blue("This is blue.")
cp.magenta("This is magenta.")
cp.cyan("This is cyan.")
cp.red('123', '456', '789')  # 多值打印
cp.color_hex("FFC0CB", "This is pink.")  # 自定义十六进制颜色值
cp.color_hex("#800080", "This is purple.")  # 自定义十六进制颜色值

```

## 展示

![效果展示1](https://img-1256814817.cos.ap-beijing.myqcloud.com/images/color1.png)

![效果展示2](https://img-1256814817.cos.ap-beijing.myqcloud.com/images/color2.png)
